==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Înregistrare video în proces. Doriți să închideți fereastra?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Deschidere fișier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotografie</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Schimbă camerele</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiere</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ștergere</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Deschidere fișier</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimare</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Dvs. nu aveți permisiune pentru manipulare cu acest directoriu.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Directoriu incorect</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Deschidere fișier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>De bază</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Locație fișier</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Fotografie</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mod rafală</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Întârziere autodeclanșator</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ieșire</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formatul de ieșire</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 buc</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 buc</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera - este instrumentul de capturare foto și video ce utilizează camera web a calculatorului dvs.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fișier nu a fost salvat</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Salvare la:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Poza:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Setări rezoluție</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Rezoluție:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Poze:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efecte sonore</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modul oglindă</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lampa de lumină</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Linii de rețea</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Linii 1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Linii 2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Rezoluție maximă:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stop înregistrare video</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiere</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ștergere</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimare</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afișați comenzile rapide</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Meniu context</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Faceți poza</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Înregistrare video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Stop</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Cald</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Rece</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Albăstruie</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>N&amp;B</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lampa de lumină</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Captură întârziată</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Expoziție</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nici-o cameră web nu a fost găsită</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Camera web este pornită</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Stop înregistrare video</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.33.tar.xz: BUILD/src/translations/deepin-camera_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Înregistrare video în proces. Doriți să închideți fereastra?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Deschidere fișier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotografie</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Schimbă camerele</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiere</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ștergere</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Deschidere fișier</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimare</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Dvs. nu aveți permisiune pentru manipulare cu acest directoriu.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Închide</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Directoriu incorect</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Deschidere fișier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>De bază</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Locație fișier</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Fotografie</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mod rafală</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Întârziere autodeclanșator</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ieșire</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formatul de ieșire</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 buc</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 buc</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera - este instrumentul de capturare foto și video ce utilizează camera web a calculatorului dvs.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fișier nu a fost salvat</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Salvare la:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Poza:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Setări rezoluție</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Rezoluție:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Poze:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efecte sonore</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modul oglindă</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Fotocamere</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Linii de rețea</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Linii 1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Linii 2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Rezoluție maximă:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stop înregistrare video</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiere</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ștergere</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimare</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afișați comenzile rapide</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Meniu context</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Faceți poza</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Înregistrare video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Stop</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Cald</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Refrigerat</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Albă-negru</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Albă-negru</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Fotocamere</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Pornit</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Oprit</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Captură întârziată</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nimic</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Expoziție</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nici-o cameră web nu a fost găsită</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Camera web este pornită</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Stop înregistrare video</translation>
    </message>
</context>
</TS>
